@@ -22,6 +22,8 @@ namespace opkele {
     class consumer_t {
 	public:
 
+	    virtual ~consumer_t() { }
+
 	    /**
 	     * store association. The function should be overridden in the real
 	     * implementation to provide persistent associations store.
@@ -29,7 +31,7 @@ namespace opkele {
 	     * @param handle association handle
 	     * @param secret the secret associated with the server and handle
 	     * @param expires_in the number of seconds until the handle is expired
-	     * @return the auto_ptr<> for the newly allocated association_t object
+	     * @return the assoc_t for the newly allocated association_t object
 	     */
 	    virtual assoc_t store_assoc(const string& server,const string& handle,const secret_t& secret,int expires_in) = 0;
 	    /**
@@ -65,8 +67,13 @@ namespace opkele {
 	     * function should never return an expired or invalidated
 	     * association.
 	     *
+	     * @note
+	     * It may be a good idea to pre-expire associations shortly before
+	     * their time is really up to avoid association expiry in the
+	     * middle of negotiations.
+	     *
 	     * @param server the OpenID server
-	     * @return the auto_ptr<> for the newly allocated association_t object
+	     * @return the assoc_t for the newly allocated association_t object
 	     * @throw failed_lookup in case of absence of the handle
 	     */
 	    virtual assoc_t find_assoc(const string& server);
@@ -86,7 +93,7 @@ namespace opkele {
 	    /**
 	     * perform the associate request to OpenID server.
 	     * @param server the OpenID server
-	     * @return the auto_ptr<> for the newly allocated association_t
+	     * @return the assoc_t for the newly allocated association_t
 	     * object, representing established association
 	     * @throw exception in case of error
 	     */
@@ -135,6 +142,7 @@ namespace opkele {
 	     * @throw id_res_setup in case of openid.user_setup_url failure
 	     * (supposedly checkid_immediate only)
 	     * @throw id_res_failed in case of failure
+	     * @throw id_res_expired_on_delivery if the association expired before it could've been verified
 	     * @throw exception in case of other failures
 	     */
 	    virtual void id_res(const params_t& pin,const string& identity="",extension_t *ext=0);
