@@ -3,6 +3,7 @@
 #include <openssl/sha.h>
 #include <openssl/hmac.h>
 #include <opkele/util.h>
+#include <opkele/util-internal.h>
 #include <opkele/exception.h>
 #include <opkele/server.h>
 #include <opkele/data.h>
@@ -109,7 +110,7 @@ namespace opkele {
 	pout["exipres_in"] = "120";
 	pout["signed"]="mode,identity,return_to";
 	if(ext) ext->checkid_hook(pin,pout);
-	pout.sign(assoc->secret(),pout["sig"],pout["signed"]);
+	pout["sig"] = util::base64_signature(assoc,pout);
     }
 
     void server_t::check_authentication(const params_t& pin,params_t& pout) {
